@@ -174,21 +174,31 @@ public:
      * Returns a list of all known applets.
      * This may skip applets based on security settings and ExcludeCategories in the application's config.
      *
-     * @param category Only applets matchin this category will be returned.
+     * @param category Only applets matching this category will be returned.
      *                 Useful in conjunction with knownCategories.
      *                 If "Misc" is passed in, then applets without a
      *                 Categories= entry are also returned.
      *                 If an empty string is passed in, all applets are
      *                 returned.
-     * @param parentApp the application to filter applets on. Uses the
-     *                  X-KDE-ParentApp entry (if any) in the plugin info.
-     *                  The default value of QString() will result in a
-     *                  list of all applets in specified categories.
      * @return list of applets
      *
      * @since 5.28
      **/
-    QList<KPluginMetaData> listAppletMetaData(const QString &category, const QString &parentApp = QString());
+    QList<KPluginMetaData> listAppletMetaData(const QString &category);
+
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 88)
+    /**
+     * @overload
+     * @param parentApp the application to filter applets on. Uses the
+     *                  X-KDE-ParentApp entry (if any) in the plugin info.
+     *                  The default value of QString() will result in a
+     *                  list of all applets in specified categories.
+     * @deprecated Since 5.88, use PluginLoader::listAppletMetaData(const QString &category)
+     * @since 5.28
+     */
+    PLASMA_DEPRECATED_VERSION(5, 88, "Use PluginLoader::listAppletMetaData(const QString &category)")
+    QList<KPluginMetaData> listAppletMetaData(const QString &category, const QString &parentApp);
+#endif
 
 #if PLASMA_ENABLE_DEPRECATED_SINCE(5, 36)
     /**
@@ -401,19 +411,24 @@ public:
      **/
     QVector<KPluginMetaData> listContainmentActionsMetaData(const QString &parentApp);
 
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 86)
     /**
      * Set the plugin loader which will be queried for all loads.
      *
      * @param loader A subclass of PluginLoader which will be supplied
      * by the application
+     * @deprecated Since 5.86, method is obsolete with the deprecation of the virtual methods
      **/
+    PLASMA_DEPRECATED_VERSION(5, 86, "Method is obsolete with the deprecation of the virtual methods")
     static void setPluginLoader(PluginLoader *loader);
+#endif
 
     /**
      * Return the active plugin loader
      **/
     static PluginLoader *self();
 
+#if PLASMA_BUILD_DEPRECATED_SINCE(5, 86)
 protected:
     /**
      * A re-implementable method that allows subclasses to override
@@ -427,7 +442,9 @@ protected:
      *        assigned automatically.
      * @param args to send the applet extra arguments
      * @return a pointer to the loaded applet, or 0 on load failure
+     * @deprecated Since 5.86, deprecated for lack of usage, use default behaviour instead
      **/
+    PLASMA_DEPRECATED_VERSION(5, 86, "Deprecated for lack of usage, use default behaviour instead")
     virtual Applet *internalLoadApplet(const QString &name, uint appletId = 0, const QVariantList &args = QVariantList());
 
     /**
@@ -439,7 +456,9 @@ protected:
      *
      * @param name the name of the engine
      * @return the data engine that was loaded, or the NullEngine on failure.
+     * @deprecated Since 5.86, deprecated for lack of usage, use default behaviour instead
      **/
+    PLASMA_DEPRECATED_VERSION(5, 86, "Deprecated for lack of usage, use default behaviour instead")
     virtual DataEngine *internalLoadDataEngine(const QString &name);
 
     /**
@@ -454,7 +473,9 @@ protected:
      * @param parent the parent object, if any, for the service
      *
      * @return a Service object, unlike Plasma::Service::loadService, this can return null.
+     * @deprecated Since 5.86, deprecated for lack of usage, use default behaviour instead
      **/
+    PLASMA_DEPRECATED_VERSION(5, 86, "Deprecated for lack of usage, use default behaviour instead")
     virtual Service *internalLoadService(const QString &name, const QVariantList &args, QObject *parent = nullptr);
 
     /**
@@ -472,10 +493,12 @@ protected:
      * @param name the plugin name, as returned by KPluginInfo::pluginName()
      * @param args to send the containmentactions extra arguments
      * @return a ContainmentActions object
+     * @deprecated Since 5.86, deprecated for lack of usage, use default behaviour instead
      **/
+    PLASMA_DEPRECATED_VERSION(5, 86, "Deprecated for lack of usage, use default behaviour instead")
     virtual ContainmentActions *internalLoadContainmentActions(Containment *parent, const QString &containmentActionsName, const QVariantList &args);
 
-#if PLASMA_BUILD_DEPRECATED_SINCE(5, 83)
+#if PLASMA_BUILD_DEPRECATED_SINCE(5, 86)
     /**
      * A re-implementable method that allows subclasses to override
      * the default behaviour of loadPackage. If the service requested is not recognized,
@@ -509,7 +532,9 @@ protected:
      *                 If an empty string is passed in, all applets are
      *                 returned.
      * @return list of applets
+     * @deprecated Since 5.86, deprecated for lack of usage, use default behaviour instead
      **/
+    PLASMA_DEPRECATED_VERSION(5, 86, "Deprecated for lack of usage, use default behaviour instead")
     virtual KPluginInfo::List internalAppletInfo(const QString &category) const;
 
     /**
@@ -517,23 +542,31 @@ protected:
      * for DataEngine::listDataEngines.
      *
      * @return list of dataengine info, or an empty list if none
+     * @deprecated Since 5.86, deprecated for lack of usage, use default behaviour instead
      **/
+    PLASMA_DEPRECATED_VERSION(5, 86, "Deprecated for lack of usage, use default behaviour instead")
     virtual KPluginInfo::List internalDataEngineInfo() const;
 
     /**
      * Returns a list of all known Service implementations
      *
      * @return list of Service info, or an empty list if none
+     * @deprecated Since 5.86, deprecated for lack of usage, use default behaviour instead
      */
+    PLASMA_DEPRECATED_VERSION(5, 86, "Deprecated for lack of usage, use default behaviour instead")
     virtual KPluginInfo::List internalServiceInfo() const;
 
     /**
      * Returns a list of all known ContainmentActions implementations
      *
      * @return list of ContainmentActions info, or an empty list if none
+     * @deprecated Since 5.86, deprecated for lack of usage, use default behaviour instead
      */
+    PLASMA_DEPRECATED_VERSION(5, 86, "Deprecated for lack of usage, use default behaviour instead")
     virtual KPluginInfo::List internalContainmentActionsInfo() const;
+#endif
 
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 88)
     /**
      * Standardized mechanism for providing internal applets by install .desktop files
      * in $APPPDATA/plasma/internal/applets/
@@ -548,7 +581,9 @@ protected:
      *                 If an empty string is passed in, all applets are
      *                 returned.
      * @return list of applets, or an empty list if none
+     * @deprecated Since 5.88, deprecated for lack of usage & obsolete with json metadata
      */
+    PLASMA_DEPRECATED_VERSION(5, 88, "deprecated for lack of usage & obsolete with json metadata")
     KPluginInfo::List standardInternalAppletInfo(const QString &category) const;
 
     /**
@@ -559,7 +594,9 @@ protected:
      * call to this method.
      *
      * @return list of dataengines
+     * @deprecated Since 5.88, deprecated for lack of usage & obsolete with json metadata
      */
+    PLASMA_DEPRECATED_VERSION(5, 88, "deprecated for lack of usage & obsolete with json metadata")
     KPluginInfo::List standardInternalDataEngineInfo() const;
 
     /**
@@ -570,15 +607,16 @@ protected:
      * call to this method.
      *
      * @return list of services
+     * @deprecated Since 5.88, deprecated for lack of usage & obsolete with json metadata
      */
+    PLASMA_DEPRECATED_VERSION(5, 88, "deprecated for lack of usage & obsolete with json metadata")
     KPluginInfo::List standardInternalServiceInfo() const;
+#endif
 
     PluginLoader();
     virtual ~PluginLoader();
 
 private:
-    bool isPluginVersionCompatible(KPluginLoader &loader);
-
     PluginLoaderPrivate *const d;
 };
 
