@@ -25,9 +25,12 @@
 #include <kdeclarative/qmlobjectsharedengine.h>
 
 #include <packageurlinterceptor.h>
-#include <private/package_p.h>
 #include <qloggingcategory.h>
 
+#if PLASMAQUICK_BUILD_DEPRECATED_SINCE(5, 36)
+#include <private/package_p.h>
+#endif
+
 namespace PlasmaQuick
 {
 QHash<QObject *, AppletQuickItem *> AppletQuickItemPrivate::s_rootObjects = QHash<QObject *, AppletQuickItem *>();
@@ -79,7 +82,7 @@ void AppletQuickItemPrivate::init()
 int AppletQuickItemPrivate::preloadWeight() const
 {
     int defaultWeight;
-    const QStringList provides(KPluginMetaData::readStringList(applet->pluginMetaData().rawData(), QStringLiteral("X-Plasma-Provides")));
+    const QStringList provides = applet->pluginMetaData().value(QStringLiteral("X-Plasma-Provides"), QStringList());
 
     // some applet types we want a bigger weight
     if (provides.contains(QLatin1String("org.kde.plasma.launchermenu"))) {
@@ -90,7 +93,7 @@ int AppletQuickItemPrivate::preloadWeight() const
     // default widgets to be barely preloaded
     return qBound(0,
                   applet->config().readEntry(QStringLiteral("PreloadWeight"),
-                                             qMax(defaultWeight, applet->pluginMetaData().rawData().value(QStringLiteral("X-Plasma-PreloadWeight")).toInt())),
+                                             qMax(defaultWeight, applet->pluginMetaData().value(QStringLiteral("X-Plasma-PreloadWeight"), 0))),
                   100);
 }
 
@@ -715,6 +718,7 @@ void AppletQuickItem::init()
     }
 }
 
+#if PLASMAQUICK_BUILD_DEPRECATED_SINCE(5, 36)
 Plasma::Package AppletQuickItem::appletPackage() const
 {
     return Plasma::Package(d->appletPackage);
@@ -734,6 +738,7 @@ void AppletQuickItem::setCoronaPackage(const Plasma::Package &package)
 {
     d->coronaPackage = package.kPackage();
 }
+#endif
 
 int AppletQuickItem::switchWidth() const
 {
